aboutsummaryrefslogtreecommitdiff
path: root/commands
diff options
context:
space:
mode:
Diffstat (limited to 'commands')
-rw-r--r--commands/Moderation/timeout.js2
-rw-r--r--commands/Pokemon/forcedrop.js4
2 files changed, 3 insertions, 3 deletions
diff --git a/commands/Moderation/timeout.js b/commands/Moderation/timeout.js
index 2e479ac..294ebd5 100644
--- a/commands/Moderation/timeout.js
+++ b/commands/Moderation/timeout.js
@@ -16,7 +16,7 @@ exports.run = async (bot, msg) => {
const member = msg.mentions.members.first();
if (!member) return await msg.reply('Who do I put in time-out?');
- msg.member.addRole(msg.guild.roles.find('name', 'Timeout'));
+ member.addRole(msg.guild.roles.find('name', 'Timeout'));
const { RichEmbed } = require('discord.js');
try {
diff --git a/commands/Pokemon/forcedrop.js b/commands/Pokemon/forcedrop.js
index 50a9acf..053bfe8 100644
--- a/commands/Pokemon/forcedrop.js
+++ b/commands/Pokemon/forcedrop.js
@@ -1,6 +1,6 @@
/** **************************************
*
* Ban: Plugin for PokeBot that powers the PokeWorld gym system.
* Copyright (C) 2018 TheEdge, jtsshieh, Alee
*
* Licensed under the Open Software License version 3.0
@@ -11,7 +11,7 @@ exports.run = async (bot, msg) => {
const isWhitelist = await bot.plugins.whitelist.isWhitelist(msg.guild.id);
if (!isWhitelist) return msg.reply ('This is a Whiltelisted command. Only whitelisted servers can use this command. Sorry!');
- if (!msg.member.hasPermission('MANAGE_MESSAGES')) return msg.reply('You don\'t have permssion to ban members.');
+ if (!msg.member.hasPermission('MANAGE_MESSAGES')) return msg.reply('You don\'t have permission to force drop.');
if (!msg.channel.name.startsWith('gym-')) return msg.reply('Go into one of the gym channels and try again.');
if (msg.channel.topic == 'Current Owner: *none*') {
msg.reply('This gym does not have an owner.');
@@ -1,6 +1,6 @@
/** **************************************
*
- * Ban: Plugin for PokeBot that powers the PokeWorld gym system.
+ * ForceDrop: Plugin for PokeBot that powers the PokeWorld gym system.
* Copyright (C) 2018 TheEdge, jtsshieh, Alee
*